module.exports = defineTest({
	description: 'deshadows top-level declarations'
});
